<?php

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

// Check if class already exists

//if (!class_exists("WPsite_Firebar_DB")):

/**
 * This class will perform all databse related tasks to manage all firebars
 *
 * @since 1.0.0
 *
 */
include_once(WPSITE_FIREBAR_PLUGIN_DIR . "/admin/model/list-table.php");

class WPsite_Firebar_DB {

	/**
	 * table_name
	 *
	 * (default value: 'wpsite_firebar')
	 *
	 * @var string
	 * @access private
	 * @static
	 */
	private static $table_name = 'wpsite_firebar';

	/**
	 * Contructor of this class.
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	Instance
	 */
	function __construct() {

		self::createTable();

	}

	/**
	 * Creates the table used to store all FireBar data
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function createTable() {
		global $wpdb;

		$wpdb->query("
			CREATE TABLE IF NOT EXISTS `" . self::getTableName() . "` (
				`id` int(11) NOT NULL AUTO_INCREMENT,
				`name` varchar(60) NOT NULL DEFAULT '',
				`title` varchar(255) NOT NULL DEFAULT '',
				`template` varchar(60) NOT NULL DEFAULT 'Text',
				`display` varchar(8) NOT NULL DEFAULT 'Bar',
				`location` varchar(8) NOT NULL DEFAULT 'Top',
				`color` varchar(8) NOT NULL DEFAULT '#ff6600',
				`text_color` varchar(8) NOT NULL DEFAULT '#000000',
				`trigger` longtext NOT NULL,
				`height` int(4) NOT NULL,
				`link_url` text NOT NULL DEFAULT '',
				`link_name` varchar(50) NOT NULL DEFAULT '',
				`text_link` longtext NOT NULL DEFAULT '',
				`social` longtext NOT NULL DEFAULT '',
				`news_letter` longtext NOT NULL DEFAULT '',
				`custom` longtext NOT NULL,
				`active` varchar(8) NOT NULL DEFAULT 'Active',
				`animation` varchar(3) NOT NULL DEFAULT 'yes',
				`args` longtext,
				PRIMARY KEY (`id`)
			) ENGINE=InnoDB DEFAULT CHARACTER SET utf8 COLLATE utf8_unicode_ci AUTO_INCREMENT=1;
		");
	}

	/**
	 * Add data
	 *
	 * @since 1.0.0
	 *
	 * @param	data to be added
	 * @return	false if error, otherwise nothing
	 */
	public function add_data($val) {

		global $wpdb;

		if(!is_array($val) || $val['name'] == "")
			return false;

		$result = $wpdb->query($wpdb->prepare("INSERT INTO `" . self::getTableName() . "` (
				`name`,
				`title`,
				`template`,
				`display`,
				`location`,
				`color`,
				`text_color`,
				`trigger`,
				`height`,
				`link_url`,
				`link_name`,
				`text_link`,
				`social`,
				`news_letter`,
				`custom`,
				`active`,
				`animation`,
				`args`
			) VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %d, %s, %s, %s, %s, %s, %s, %s, %s, %s)",
				$val['name'],
				$val['title'],
				$val['template'],
				$val['display'],
				$val['location'],
				$val['color'],
				$val['text_color'],
				serialize($val['trigger']),
				$val['height'],
				$val['link_url'],
				$val['link_name'],
				serialize($val['text_link']),
				serialize($val['social']),
				serialize($val['news_letter']),
				$val['custom'],
				$val['active'],
				$val['animation'],
				serialize($val['args']))
		);

		return $wpdb->insert_id;
	}

	/**
	 * Update data
	 *
	 * @since 1.0.0
	 *
	 * @param	data to be updated
	 * @return	false if error, otherwise nothing
	 */
	public function update_data($val) {

		global $wpdb;

		if (!is_array($val) || $val['id'] == "") {
			return false;
		}

		$result = $wpdb->query($wpdb->prepare(
			"UPDATE `" . self::getTableName() . "` SET
				`name` = %s,
				`title` = %s,
				`template` = %s,
				`display` = %s,
				`location` = %s,
				`color` = %s,
				`text_color` = %s,
				`trigger` = %s,
				`height` = %d,
				`link_url` = %s,
				`link_name` = %s,
				`text_link` = %s,
				`social` = %s,
				`news_letter` = %s,
				`custom` = %s,
				`active` = %s,
				`animation` = %s,
				`args` = %s
			WHERE id = %d",
				$val['name'],
				$val['title'],
				$val['template'],
				$val['display'],
				$val['location'],
				$val['color'],
				$val['text_color'],
				serialize($val['trigger']),
				$val['height'],
				$val['link_url'],
				$val['link_name'],
				serialize($val['text_link']),
				serialize($val['social']),
				serialize($val['news_letter']),
				$val['custom'],
				$val['active'],
				$val['animation'],
				serialize($val['args']),
				$val['id']
			)
		);

		if (!$result) {
			return false;
		}
	}

	/**
	 * Get the data from id
	 *
	 * @since 1.0.0
	 *
	 * @param	id
	 * @return	data of firebar
	 */
	public function get_data_from_id($id) {

		global $wpdb;

		$data = $wpdb->get_results($wpdb->prepare("SELECT * FROM `" . self::getTableName() . "` WHERE `id` = %d;", $id), 'ARRAY_A');

		foreach($data as $row) {
			$val = array();

			$val["id"]			= $row["id"];
			$val["name"]		= $row["name"];
			$val["title"]		= $row["title"];
			$val["template"] 	= $row["template"];
			$val["display"]		= $row["display"];
			$val["location"]	= $row['location'];
			$val["color"]		= $row['color'];
			$val["text_color"]	= $row['text_color'];
			$val["trigger"] 	= $row["trigger"];
			$val["height"] 		= $row["height"];
			$val["link_url"] 	= $row["link_url"];
			$val["link_name"] 	= $row["link_name"];
			$val["text_link"] 	= $row["text_link"];
			$val["social"] 		= $row["social"];
			$val["news_letter"] = $row["news_letter"];
			$val["custom"]		= $row["custom"];
			$val["active"]		= $row["active"];
			$val["animation"]	= $row["animation"];
			$val["args"] 		= $row["args"];
		}

		return $val;
	}

	/**
	 * Set to active or inactive
	 *
	 * @since 1.0.0
	 *
	 * @param	record id
	 * @param	value to set
	 * @return	false if error, otherwise nothing
	 */
	public function set_active($id, $active) {

		global $wpdb;

		$result = $wpdb->query($wpdb->prepare("UPDATE `" . self::getTableName() . "` SET `active` = %s WHERE `id` = %d", $active, $id));
	}

	/**
	 * Delete data from id
	 *
	 * @since 1.0.0
	 *
	 * @param	id
	 * @return	N/A
	 */
	public function delete_data($id) {

		global $wpdb;

		$result = $wpdb->query($wpdb->prepare("DELETE FROM `" . self::getTableName() . "` WHERE `id` = %d", $id));
	}

	/**
	 * Returns the table name with multisite support
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	public static function getTableName() {

		global $wpdb;

		return $wpdb->prefix . self::$table_name;
	}
}

//endif;
?>